Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(318)

Unified Diff: components/autofill/content/renderer/password_generation_agent.cc

Issue 2750323003: [Password Manager] Replace WebInputElement.setValue with WebInputElement.setAutofillValue (Closed)
Patch Set: Fixed a comment Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/autofill/content/renderer/password_autofill_agent.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/autofill/content/renderer/password_generation_agent.cc
diff --git a/components/autofill/content/renderer/password_generation_agent.cc b/components/autofill/content/renderer/password_generation_agent.cc
index aed445775c7847b3348efd69a68ae69fff2ceb43..868e950521d1c8798152c9fb81ef26500de4d054 100644
--- a/components/autofill/content/renderer/password_generation_agent.cc
+++ b/components/autofill/content/renderer/password_generation_agent.cc
@@ -109,7 +109,7 @@ void CopyElementValueToOtherInputElements(
std::vector<blink::WebInputElement>* elements) {
for (blink::WebInputElement& it : *elements) {
if (*element != it) {
- it.setValue(element->value(), true /* sendEvents */);
+ it.setAutofillValue(element->value());
}
}
}
@@ -318,9 +318,9 @@ void PasswordGenerationAgent::GeneratedPasswordAccepted(
password_generation::PASSWORD_ACCEPTED);
LogMessage(Logger::STRING_GENERATION_RENDERER_GENERATED_PASSWORD_ACCEPTED);
for (auto& password_element : generation_form_data_->password_elements) {
- password_element.setValue(blink::WebString::fromUTF16(password),
- true /* sendEvents */);
- // setValue() above may have resulted in JavaScript closing the frame.
+ password_element.setAutofillValue(blink::WebString::fromUTF16(password));
+ // setAutofillValue() above may have resulted in JavaScript closing the
+ // frame.
if (!render_frame())
return;
password_element.setAutofilled(true);
« no previous file with comments | « components/autofill/content/renderer/password_autofill_agent.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698